check_quizzes: Check Quizzes

Description Usage Arguments Value Examples

View source: R/quiz.R

Description

Check Quizzes

Usage

1
2
3
check_quizzes(path = "manuscript", verbose = TRUE)

check_quiz(path, verbose = TRUE)

Arguments

path

either a path to the directory of quizzes or a full path to a quiz markdown file

verbose

print diagnostic messages

Value

A list of logical indicators

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
x = c('{quiz, id: quiz_00_filename}',
"### Lesson Name quiz",
"{choose-answers: 4}",
"? What do you think?",
"C) The answer to this one",
"o) Not the answer",
"o) Not the answer either",
"C) Another correct answer",
"m) Mandatory different answer",
"{/quiz}")
tdir = tempfile()
dir.create(tdir, showWarnings = FALSE, recursive = TRUE)
tfile = tempfile(pattern = "quiz_", fileext = ".md", tmpdir = tdir)
writeLines(x, tfile)
check_quizzes(path = tdir)

check_quiz(x)

muschellij2/leanbuild documentation built on Dec. 21, 2021, 11:03 p.m.