Description Usage Arguments Value Examples
Check Quizzes
1 2 3 | check_quizzes(path = "manuscript", verbose = TRUE)
check_quiz(path, verbose = TRUE)
|
path |
either a path to the directory of quizzes or a full path to a quiz markdown file |
verbose |
print diagnostic messages |
A list of logical indicators
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | x = c('{quiz, id: quiz_00_filename}',
"### Lesson Name quiz",
"{choose-answers: 4}",
"? What do you think?",
"C) The answer to this one",
"o) Not the answer",
"o) Not the answer either",
"C) Another correct answer",
"m) Mandatory different answer",
"{/quiz}")
tdir = tempfile()
dir.create(tdir, showWarnings = FALSE, recursive = TRUE)
tfile = tempfile(pattern = "quiz_", fileext = ".md", tmpdir = tdir)
writeLines(x, tfile)
check_quizzes(path = tdir)
check_quiz(x)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.